@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
     :codeauthor: :email:`Alexandru Bleotu (alexandru.bleotu@morganstanley.com)`
 
 
@@ -7,35 +7,29 @@
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
     ESX Datacenter configuration schemas
-'''
+"""
 
 # Import Python libs
 from __future__ import absolute_import, print_function, unicode_literals
 
 # Import Salt libs
-from salt.utils.schema import (Schema,
-                               ArrayItem,
-                               IntegerItem,
-                               StringItem)
+from salt.utils.schema import ArrayItem, IntegerItem, Schema, StringItem
 
 
 class EsxdatacenterProxySchema(Schema):
-    '''
+    """
     Schema of the esxdatacenter proxy input
-    '''
+    """
 
-    title = 'Esxdatacenter Proxy Schema'
-    description = 'Esxdatacenter proxy schema'
+    title = "Esxdatacenter Proxy Schema"
+    description = "Esxdatacenter proxy schema"
     additional_properties = False
-    proxytype = StringItem(required=True,
-                           enum=['esxdatacenter'])
-    vcenter = StringItem(required=True, pattern=r'[^\s]+')
+    proxytype = StringItem(required=True, enum=["esxdatacenter"])
+    vcenter = StringItem(required=True, pattern=r"[^\s]+")
     datacenter = StringItem(required=True)
-    mechanism = StringItem(required=True, enum=['userpass', 'sspi'])
+    mechanism = StringItem(required=True, enum=["userpass", "sspi"])
     username = StringItem()
-    passwords = ArrayItem(min_items=1,
-                          items=StringItem(),
-                          unique_items=True)
+    passwords = ArrayItem(min_items=1, items=StringItem(), unique_items=True)
     # TODO Should be changed when anyOf is supported for schemas
     domain = StringItem()
     principal = StringItem()
