@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Salt module to manage Kubernetes cluster
 
 .. versionadded:: 2016.3.0
@@ -12,49 +12,51 @@ Roadmap:
 * Add rolling update
 * Add (auto)scalling
 
-'''
+"""
 
-from __future__ import absolute_import, unicode_literals, print_function
+from __future__ import absolute_import, print_function, unicode_literals
 
+import base64
+import logging as logger
 import os
 import re
-import logging as logger
-import base64
-from salt.ext import six
-from salt.ext.six.moves.urllib.parse import urlparse as _urlparse  # pylint: disable=no-name-in-module
-
-# TODO Remove requests dependency
 
 import salt.utils.files
 import salt.utils.http as http
 import salt.utils.json
+from salt.ext import six
+from salt.ext.six.moves.urllib.parse import urlparse as _urlparse
 
-__virtualname__ = 'k8s'
+# TODO Remove requests dependency
+
+
+__virtualname__ = "k8s"
 
 # Setup the logger
 log = logger.getLogger(__name__)
 
 
 def __virtual__():
-    '''Load load if python-requests is installed.'''
+    """Load load if python-requests is installed."""
     return __virtualname__
 
 
 def _guess_apiserver(apiserver_url=None):
-    '''Try to guees the kubemaster url from environ,
+    """Try to guees the kubemaster url from environ,
     then from `/etc/kubernetes/config` file
-    '''
+    """
     default_config = "/etc/kubernetes/config"
     if apiserver_url is not None:
         return apiserver_url
     if "KUBERNETES_MASTER" in os.environ:
         apiserver_url = os.environ.get("KUBERNETES_MASTER")
-    elif __salt__['config.get']('k8s:master'):
-        apiserver_url = __salt__['config.get']('k8s:master')
-    elif os.path.exists(default_config) or __salt__['config.get']('k8s:config', ""):
-        config = __salt__['config.get']('k8s:config', default_config)
-        kubeapi_regex = re.compile("""KUBE_MASTER=['"]--master=(.*)['"]""",
-                                   re.MULTILINE)
+    elif __salt__["config.get"]("k8s:master"):
+        apiserver_url = __salt__["config.get"]("k8s:master")
+    elif os.path.exists(default_config) or __salt__["config.get"]("k8s:config", ""):
+        config = __salt__["config.get"]("k8s:config", default_config)
+        kubeapi_regex = re.compile(
+            """KUBE_MASTER=['"]--master=(.*)['"]""", re.MULTILINE
+        )
         with salt.utils.files.fopen(config) as fh_k8s:
             for line in fh_k8s.readlines():
                 match_line = kubeapi_regex.match(line)
@@ -68,58 +70,57 @@ def _guess_apiserver(apiserver_url=None):
 
 
 def _kpost(url, data):
-    ''' create any object in kubernetes based on URL '''
+    """ create any object in kubernetes based on URL """
 
     # Prepare headers
     headers = {"Content-Type": "application/json"}
     # Make request
     log.trace("url is: %s, data is: %s", url, data)
-    ret = http.query(url,
-                     method='POST',
-                     header_dict=headers,
-                     data=salt.utils.json.dumps(data))
+    ret = http.query(
+        url, method="POST", header_dict=headers, data=salt.utils.json.dumps(data)
+    )
     # Check requests status
-    if ret.get('error'):
+    if ret.get("error"):
         return ret
     else:
-        return salt.utils.json.loads(ret.get('body'))
+        return salt.utils.json.loads(ret.get("body"))
 
 
 def _kput(url, data):
-    ''' put any object in kubernetes based on URL '''
+    """ put any object in kubernetes based on URL """
 
     # Prepare headers
     headers = {"Content-Type": "application/json"}
     # Make request
-    ret = http.query(url,
-                     method='PUT',
-                     header_dict=headers,
-                     data=salt.utils.json.dumps(data))
+    ret = http.query(
+        url, method="PUT", header_dict=headers, data=salt.utils.json.dumps(data)
+    )
     # Check requests status
-    if ret.get('error'):
+    if ret.get("error"):
         return ret
     else:
-        return salt.utils.json.loads(ret.get('body'))
+        return salt.utils.json.loads(ret.get("body"))
 
 
 def _kpatch(url, data):
-    ''' patch any object in kubernetes based on URL '''
+    """ patch any object in kubernetes based on URL """
 
     # Prepare headers
     headers = {"Content-Type": "application/json-patch+json"}
     # Make request
-    ret = http.query(url, method='PATCH', header_dict=headers,
-                     data=salt.utils.json.dumps(data))
+    ret = http.query(
+        url, method="PATCH", header_dict=headers, data=salt.utils.json.dumps(data)
+    )
     # Check requests status
-    if ret.get('error'):
+    if ret.get("error"):
         log.error("Got an error: %s", ret.get("error"))
         return ret
     else:
-        return salt.utils.json.loads(ret.get('body'))
+        return salt.utils.json.loads(ret.get("body"))
 
 
 def _kname(obj):
-    '''Get name or names out of json result from API server'''
+    """Get name or names out of json result from API server"""
     if isinstance(obj, dict):
         return [obj.get("metadata", {}).get("name", "")]
     elif isinstance(obj, (list, tuple)):
@@ -132,8 +133,8 @@ def _kname(obj):
 
 
 def _is_dns_subdomain(name):
-    ''' Check that name is DNS subdomain: One or more lowercase rfc1035/rfc1123
-    labels separated by '.' with a maximum length of 253 characters '''
+    """ Check that name is DNS subdomain: One or more lowercase rfc1035/rfc1123
+    labels separated by '.' with a maximum length of 253 characters """
 
     dns_subdomain = re.compile(r"""^[a-z0-9\.-]{1,253}$""")
     if dns_subdomain.match(name):
@@ -145,10 +146,10 @@ def _is_dns_subdomain(name):
 
 
 def _is_port_name(name):
-    ''' Check that name is IANA service: An alphanumeric (a-z, and 0-9) string,
+    """ Check that name is IANA service: An alphanumeric (a-z, and 0-9) string,
     with a maximum length of 15 characters, with the '-' character allowed
     anywhere except the first or the last character or adjacent to another '-'
-    character, it must contain at least a (a-z) character '''
+    character, it must contain at least a (a-z) character """
 
     port_name = re.compile("""^[a-z0-9]{1,15}$""")
     if port_name.match(name):
@@ -158,10 +159,10 @@ def _is_port_name(name):
 
 
 def _is_dns_label(name):
-    ''' Check that name is DNS label: An alphanumeric (a-z, and 0-9) string,
+    """ Check that name is DNS label: An alphanumeric (a-z, and 0-9) string,
     with a maximum length of 63 characters, with the '-' character allowed
     anywhere except the first or last character, suitable for use as a hostname
-    or segment in a domain name '''
+    or segment in a domain name """
 
     dns_label = re.compile(r"""^[a-z0-9][a-z0-9\.-]{1,62}$""")
     if dns_label.match(name):
@@ -171,31 +172,31 @@ def _is_dns_label(name):
 
 
 def _guess_node_id(node):
-    '''Try to guess kube node ID using salt minion ID'''
+    """Try to guess kube node ID using salt minion ID"""
     if node is None:
-        return __salt__['grains.get']('id')
+        return __salt__["grains.get"]("id")
     return node
 
 
 def _get_labels(node, apiserver_url):
-    '''Get all labels from a kube node.'''
+    """Get all labels from a kube node."""
     # Prepare URL
     url = "{0}/api/v1/nodes/{1}".format(apiserver_url, node)
     # Make request
     ret = http.query(url)
     # Check requests status
-    if 'body' in ret:
-        ret = salt.utils.json.loads(ret.get('body'))
-    elif ret.get('status', 0) == 404:
+    if "body" in ret:
+        ret = salt.utils.json.loads(ret.get("body"))
+    elif ret.get("status", 0) == 404:
         return "Node {0} doesn't exist".format(node)
     else:
         return ret
     # Get and return labels
-    return ret.get('metadata', {}).get('labels', {})
+    return ret.get("metadata", {}).get("labels", {})
 
 
 def _set_labels(node, apiserver_url, labels):
-    '''Replace labels dict by a new one'''
+    """Replace labels dict by a new one"""
     # Prepare URL
     url = "{0}/api/v1/nodes/{1}".format(apiserver_url, node)
     # Prepare data
@@ -208,8 +209,9 @@ def _set_labels(node, apiserver_url, labels):
 
 
 def get_labels(node=None, apiserver_url=None):
-    '''
+    """
     .. versionadded:: 2016.3.0
+
     Get labels from the current node
 
     CLI Example:
@@ -219,7 +221,7 @@ def get_labels(node=None, apiserver_url=None):
         salt '*' k8s.get_labels
         salt '*' k8s.get_labels kube-node.cluster.local http://kube-master.cluster.local
 
-    '''
+    """
     # Get salt minion ID
     node = _guess_node_id(node)
     # Try to get kubernetes master
@@ -234,7 +236,7 @@ def get_labels(node=None, apiserver_url=None):
 
 
 def label_present(name, value, node=None, apiserver_url=None):
-    '''
+    """
     .. versionadded:: 2016.3.0
 
     Set label to the current node
@@ -247,8 +249,8 @@ def label_present(name, value, node=None, apiserver_url=None):
 
         salt '*' k8s.label_present hw/disktype ssd kube-node.cluster.local http://kube-master.cluster.local
 
-    '''
-    ret = {'name': name, 'result': True, 'comment': '', 'changes': {}}
+    """
+    ret = {"name": name, "result": True, "comment": "", "changes": {}}
 
     # Get salt minion ID
     node = _guess_node_id(node)
@@ -262,37 +264,37 @@ def label_present(name, value, node=None, apiserver_url=None):
 
     if name not in labels:
         # This is a new label
-        ret['changes'] = {name: value}
+        ret["changes"] = {name: value}
         labels[name] = str(value)
         res = _set_labels(node, apiserver_url, labels)
-        if res.get('status') == 409:
+        if res.get("status") == 409:
             # there is an update during operation, need to retry
             log.debug("Got 409, will try later")
-            ret['changes'] = {}
-            ret['comment'] = "Could not create label {0}, please retry".format(name)
+            ret["changes"] = {}
+            ret["comment"] = "Could not create label {0}, please retry".format(name)
         else:
-            ret['comment'] = "Label {0} created".format(name)
+            ret["comment"] = "Label {0} created".format(name)
     elif labels.get(name) != str(value):
         # This is a old label and we are going to edit it
-        ret['changes'] = {name: str(value)}
+        ret["changes"] = {name: str(value)}
         labels[name] = str(value)
         res = _set_labels(node, apiserver_url, labels)
-        if res.get('status') == 409:
+        if res.get("status") == 409:
             # there is an update during operation, need to retry
             log.debug("Got 409, will try later")
-            ret['changes'] = {}
-            ret['comment'] = "Could not update label {0}, please retry".format(name)
+            ret["changes"] = {}
+            ret["comment"] = "Could not update label {0}, please retry".format(name)
         else:
-            ret['comment'] = "Label {0} updated".format(name)
+            ret["comment"] = "Label {0} updated".format(name)
     else:
         # This is a old label and it has already the wanted value
-        ret['comment'] = "Label {0} already set".format(name)
+        ret["comment"] = "Label {0} already set".format(name)
 
     return ret
 
 
 def label_absent(name, node=None, apiserver_url=None):
-    '''
+    """
     .. versionadded:: 2016.3.0
 
     Delete label to the current node
@@ -304,8 +306,8 @@ def label_absent(name, node=None, apiserver_url=None):
         salt '*' k8s.label_absent hw/disktype
         salt '*' k8s.label_absent hw/disktype kube-node.cluster.local http://kube-master.cluster.local
 
-    '''
-    ret = {'name': name, 'result': True, 'comment': '', 'changes': {}}
+    """
+    ret = {"name": name, "result": True, "comment": "", "changes": {}}
 
     # Get salt minion ID
     node = _guess_node_id(node)
@@ -317,29 +319,28 @@ def label_absent(name, node=None, apiserver_url=None):
     # Get all labels
     old_labels = _get_labels(node, apiserver_url)
     # Prepare a temp labels dict
-    labels = dict([(key, value) for key, value in old_labels.items()
-                   if key != name])
+    labels = dict([(key, value) for key, value in old_labels.items() if key != name])
     # Compare old labels and what we want
     if labels == old_labels:
         # Label already absent
-        ret['comment'] = "Label {0} already absent".format(name)
+        ret["comment"] = "Label {0} already absent".format(name)
     else:
         # Label needs to be delete
         res = _set_labels(node, apiserver_url, labels)
-        if res.get('status') == 409:
+        if res.get("status") == 409:
             # there is an update during operation, need to retry
             log.debug("Got 409, will try later")
-            ret['changes'] = {}
-            ret['comment'] = "Could not delete label {0}, please retry".format(name)
+            ret["changes"] = {}
+            ret["comment"] = "Could not delete label {0}, please retry".format(name)
         else:
-            ret['changes'] = {"deleted": name}
-            ret['comment'] = "Label {0} absent".format(name)
+            ret["changes"] = {"deleted": name}
+            ret["comment"] = "Label {0} absent".format(name)
 
     return ret
 
 
 def label_folder_absent(name, node=None, apiserver_url=None):
-    '''
+    """
     .. versionadded:: 2016.3.0
 
     Delete label folder to the current node
@@ -351,9 +352,9 @@ def label_folder_absent(name, node=None, apiserver_url=None):
         salt '*' k8s.label_folder_absent hw
         salt '*' k8s.label_folder_absent hw/ kube-node.cluster.local http://kube-master.cluster.local
 
-    '''
+    """
     folder = name.strip("/") + "/"
-    ret = {'name': folder, 'result': True, 'comment': '', 'changes': {}}
+    ret = {"name": folder, "result": True, "comment": "", "changes": {}}
 
     # Get salt minion ID
     node = _guess_node_id(node)
@@ -365,29 +366,36 @@ def label_folder_absent(name, node=None, apiserver_url=None):
     # Get all labels
     old_labels = _get_labels(node, apiserver_url)
     # Prepare a temp labels dict
-    labels = dict([(key, value) for key, value in old_labels.items()
-                   if not key.startswith(folder)])
+    labels = dict(
+        [
+            (key, value)
+            for key, value in old_labels.items()
+            if not key.startswith(folder)
+        ]
+    )
     # Prepare a temp labels dict
     if labels == old_labels:
         # Label already absent
-        ret['comment'] = "Label folder {0} already absent".format(folder)
+        ret["comment"] = "Label folder {0} already absent".format(folder)
     else:
         # Label needs to be delete
         res = _set_labels(node, apiserver_url, labels)
-        if res.get('status') == 409:
+        if res.get("status") == 409:
             log.debug("Got 409, will try later")
-            ret['changes'] = {}
-            ret['comment'] = "Could not delete label folder {0}, please retry".format(folder)
+            ret["changes"] = {}
+            ret["comment"] = "Could not delete label folder {0}, please retry".format(
+                folder
+            )
         else:
-            ret['changes'] = {"deleted": folder}
-            ret['comment'] = "Label folder {0} absent".format(folder)
+            ret["changes"] = {"deleted": folder}
+            ret["comment"] = "Label folder {0} absent".format(folder)
 
     return ret
 
 
 # Namespaces
 def _get_namespaces(apiserver_url, name=""):
-    '''Get namespace is namespace is defined otherwise return all namespaces'''
+    """Get namespace is namespace is defined otherwise return all namespaces"""
     # Prepare URL
     url = "{0}/api/v1/namespaces/{1}".format(apiserver_url, name)
     # Make request
@@ -399,17 +407,11 @@ def _get_namespaces(apiserver_url, name=""):
 
 
 def _create_namespace(namespace, apiserver_url):
-    ''' create namespace on the defined k8s cluster '''
+    """ create namespace on the defined k8s cluster """
     # Prepare URL
     url = "{0}/api/v1/namespaces".format(apiserver_url)
     # Prepare data
-    data = {
-        "kind": "Namespace",
-        "apiVersion": "v1",
-        "metadata": {
-            "name": namespace,
-        }
-    }
+    data = {"kind": "Namespace", "apiVersion": "v1", "metadata": {"name": namespace}}
     log.trace("namespace creation requests: %s", data)
     # Make request
     ret = _kpost(url, data)
@@ -419,7 +421,7 @@ def _create_namespace(namespace, apiserver_url):
 
 
 def create_namespace(name, apiserver_url=None):
-    '''
+    """
     .. versionadded:: 2016.3.0
 
     Create kubernetes namespace from the name, similar to the functionality added to kubectl since v.1.2.0:
@@ -435,8 +437,8 @@ def create_namespace(name, apiserver_url=None):
 
         salt '*' k8s.create_namespace namespace_name http://kube-master.cluster.local
 
-    '''
-    ret = {'name': name, 'result': True, 'comment': '', 'changes': {}}
+    """
+    ret = {"name": name, "result": True, "comment": "", "changes": {}}
 
     # Try to get kubernetes master
     apiserver_url = _guess_apiserver(apiserver_url)
@@ -446,15 +448,15 @@ def create_namespace(name, apiserver_url=None):
     if not _get_namespaces(apiserver_url, name):
         # This is a new namespace
         _create_namespace(name, apiserver_url)
-        ret['changes'] = name
-        ret['comment'] = "Namespace {0} created".format(name)
+        ret["changes"] = name
+        ret["comment"] = "Namespace {0} created".format(name)
     else:
-        ret['comment'] = "Namespace {0} already present".format(name)
+        ret["comment"] = "Namespace {0} already present".format(name)
     return ret
 
 
 def get_namespaces(namespace="", apiserver_url=None):
-    '''
+    """
     .. versionadded:: 2016.3.0
 
     Get one or all kubernetes namespaces.
@@ -479,7 +481,7 @@ def get_namespaces(namespace="", apiserver_url=None):
         salt '*' k8s.get_namespaces
         salt '*' k8s.get_namespaces namespace_name http://kube-master.cluster.local
 
-    '''
+    """
     # Try to get kubernetes master
     apiserver_url = _guess_apiserver(apiserver_url)
     if apiserver_url is None:
@@ -492,10 +494,9 @@ def get_namespaces(namespace="", apiserver_url=None):
 
 # Secrets
 def _get_secrets(namespace, name, apiserver_url):
-    '''Get secrets of the namespace.'''
+    """Get secrets of the namespace."""
     # Prepare URL
-    url = "{0}/api/v1/namespaces/{1}/secrets/{2}".format(apiserver_url,
-                                                         namespace, name)
+    url = "{0}/api/v1/namespaces/{1}/secrets/{2}".format(apiserver_url, namespace, name)
     # Make request
     ret = http.query(url)
     if ret.get("body"):
@@ -505,10 +506,9 @@ def _get_secrets(namespace, name, apiserver_url):
 
 
 def _update_secret(namespace, name, data, apiserver_url):
-    '''Replace secrets data by a new one'''
+    """Replace secrets data by a new one"""
     # Prepare URL
-    url = "{0}/api/v1/namespaces/{1}/secrets/{2}".format(apiserver_url,
-                                                         namespace, name)
+    url = "{0}/api/v1/namespaces/{1}/secrets/{2}".format(apiserver_url, namespace, name)
     # Prepare data
     data = [{"op": "replace", "path": "/data", "value": data}]
     # Make request
@@ -519,18 +519,15 @@ def _update_secret(namespace, name, data, apiserver_url):
 
 
 def _create_secret(namespace, name, data, apiserver_url):
-    ''' create namespace on the defined k8s cluster '''
+    """ create namespace on the defined k8s cluster """
     # Prepare URL
     url = "{0}/api/v1/namespaces/{1}/secrets".format(apiserver_url, namespace)
     # Prepare data
     request = {
         "apiVersion": "v1",
         "kind": "Secret",
-        "metadata": {
-            "name": name,
-            "namespace": namespace,
-        },
-        "data": data
+        "metadata": {"name": name, "namespace": namespace},
+        "data": data,
     }
     # Make request
     ret = _kpost(url, request)
@@ -558,17 +555,17 @@ def _decode_secrets(secrets):
         for i, secret in enumerate(items):
             log.trace(i, secret)
             for k, v in six.iteritems(secret.get("data", {})):
-                items[i]['data'][k] = base64.b64decode(v)
+                items[i]["data"][k] = base64.b64decode(v)
         secrets["items"] = items
         return secrets
     else:
         for k, v in six.iteritems(secrets.get("data", {})):
-            secrets['data'][k] = base64.b64decode(v)
+            secrets["data"][k] = base64.b64decode(v)
         return secrets
 
 
 def get_secrets(namespace, name="", apiserver_url=None, decode=False, brief=False):
-    '''
+    """
     Get k8s namespaces
 
     CLI Example:
@@ -578,7 +575,7 @@ def get_secrets(namespace, name="", apiserver_url=None, decode=False, brief=Fals
         salt '*' k8s.get_secrets namespace_name
         salt '*' k8s.get_secrets namespace_name secret_name http://kube-master.cluster.local
 
-    '''
+    """
     # Try to get kubernetes master
     apiserver_url = _guess_apiserver(apiserver_url)
     if apiserver_url is None:
@@ -596,12 +593,12 @@ def _source_encode(source, saltenv):
     try:
         source_url = _urlparse(source)
     except TypeError:
-        return '', {}, ('Invalid format for source parameter')
+        return "", {}, ("Invalid format for source parameter")
 
-    protos = ('salt', 'http', 'https', 'ftp', 'swift', 's3', 'file')
+    protos = ("salt", "http", "https", "ftp", "swift", "s3", "file")
 
     log.trace("parsed source looks like: %s", source_url)
-    if not source_url.scheme or source_url.scheme == 'file':
+    if not source_url.scheme or source_url.scheme == "file":
         # just a regular file
         filename = os.path.abspath(source_url.path)
         sname = os.path.basename(filename)
@@ -611,7 +608,7 @@ def _source_encode(source, saltenv):
     else:
         if source_url.scheme in protos:
             # The source is a file on a server
-            filename = __salt__['cp.cache_file'](source, saltenv)
+            filename = __salt__["cp.cache_file"](source, saltenv)
             if not filename:
                 log.warning("Source file: %s can not be retrieved", source)
                 return "", ""
@@ -619,8 +616,10 @@ def _source_encode(source, saltenv):
     return "", ""
 
 
-def update_secret(namespace, name, sources, apiserver_url=None, force=True, saltenv='base'):
-    '''
+def update_secret(
+    namespace, name, sources, apiserver_url=None, force=True, saltenv="base"
+):
+    """
     .. versionadded:: 2016.3.0
 
     alias to k8s.create_secret with update=true
@@ -655,16 +654,31 @@ def update_secret(namespace, name, sources, apiserver_url=None, force=True, salt
     saltenv=['base'] default value is base
     in case 'salt://' path is used, this parameter can change the visibility of files
 
-    '''
+    """
     apiserver_url = _guess_apiserver(apiserver_url)
 
-    ret = create_secret(namespace, name, sources, apiserver_url=apiserver_url,
-                        force=force, update=True, saltenv=saltenv)
+    ret = create_secret(
+        namespace,
+        name,
+        sources,
+        apiserver_url=apiserver_url,
+        force=force,
+        update=True,
+        saltenv=saltenv,
+    )
     return ret
 
 
-def create_secret(namespace, name, sources, apiserver_url=None, force=False, update=False, saltenv='base'):
-    '''
+def create_secret(
+    namespace,
+    name,
+    sources,
+    apiserver_url=None,
+    force=False,
+    update=False,
+    saltenv="base",
+):
+    """
     .. versionadded:: 2016.3.0
 
     Create k8s secrets in the defined namespace from the list of files
@@ -706,11 +720,16 @@ def create_secret(namespace, name, sources, apiserver_url=None, force=False, upd
     saltenv=['base'] default value is base
     in case 'salt://' path is used, this parameter can change the visibility of files
 
-    '''
-    ret = {'name': name, 'result': True, 'comment': '', 'changes': {}}
+    """
+    ret = {"name": name, "result": True, "comment": "", "changes": {}}
 
     if not sources:
-        return {'name': name, 'result': False, 'comment': 'No source available', 'changes': {}}
+        return {
+            "name": name,
+            "result": False,
+            "comment": "No source available",
+            "changes": {},
+        }
 
     apiserver_url = _guess_apiserver(apiserver_url)
     # we need namespace to create secret in it
@@ -718,14 +737,22 @@ def create_secret(namespace, name, sources, apiserver_url=None, force=False, upd
         if force:
             _create_namespace(namespace, apiserver_url)
         else:
-            return {'name': name, 'result': False, 'comment': "Namespace doesn't exists", 'changes': {}}
+            return {
+                "name": name,
+                "result": False,
+                "comment": "Namespace doesn't exists",
+                "changes": {},
+            }
 
     secret = _get_secrets(namespace, name, apiserver_url)
     if secret and not update:
         log.info("Secret %s is already present on %s", name, namespace)
-        return {'name': name, 'result': False,
-                'comment': 'Secret {0} is already present'.format(name),
-                'changes': {}}
+        return {
+            "name": name,
+            "result": False,
+            "comment": "Secret {0} is already present".format(name),
+            "changes": {},
+        }
 
     data = {}
 
@@ -738,7 +765,9 @@ def create_secret(namespace, name, sources, apiserver_url=None, force=False, upd
             for k, v in six.iteritems(source):
                 sname, encoded = _source_encode(v, saltenv)
                 if sname == encoded == "":
-                    ret['comment'] += "Source file {0} is missing or name is incorrect\n".format(v)
+                    ret[
+                        "comment"
+                    ] += "Source file {0} is missing or name is incorrect\n".format(v)
                     if force:
                         continue
                     else:
@@ -749,13 +778,17 @@ def create_secret(namespace, name, sources, apiserver_url=None, force=False, upd
             sname, encoded = _source_encode(source, saltenv)
             if sname == encoded == "":
                 if force:
-                    ret['comment'] += "Source file {0} is missing or name is incorrect\n".format(source)
+                    ret[
+                        "comment"
+                    ] += "Source file {0} is missing or name is incorrect\n".format(
+                        source
+                    )
                     continue
                 else:
                     return ret
             data[sname] = encoded
 
-    log.trace("secret data is: {0}".format(data))
+    log.trace("secret data is: %s", data)
 
     if secret and update:
         if not data:
@@ -763,18 +796,18 @@ def create_secret(namespace, name, sources, apiserver_url=None, force=False, upd
             ret["result"] = False
         elif secret.get("data") and data != secret.get("data"):
             res = _update_secret(namespace, name, data, apiserver_url)
-            ret['comment'] = 'Updated secret'
-            ret['changes'] = 'Updated secret'
+            ret["comment"] = "Updated secret"
+            ret["changes"] = "Updated secret"
         else:
             log.debug("Secret has not been changed on cluster, skipping it")
-            ret['comment'] = 'Has not been changed on cluster, skipping it'
+            ret["comment"] = "Has not been changed on cluster, skipping it"
     else:
         res = _create_secret(namespace, name, data, apiserver_url)
     return ret
 
 
 def delete_secret(namespace, name, apiserver_url=None, force=True):
-    '''
+    """
     .. versionadded:: 2016.3.0
 
     Delete kubernetes secret in the defined namespace. Namespace is the mandatory parameter as well as name.
@@ -787,8 +820,8 @@ def delete_secret(namespace, name, apiserver_url=None, force=True):
 
         salt '*' k8s.delete_secret namespace_name secret_name http://kube-master.cluster.local
 
-    '''
-    ret = {'name': name, 'result': True, 'comment': '', 'changes': {}}
+    """
+    ret = {"name": name, "result": True, "comment": "", "changes": {}}
 
     # Try to get kubernetes master
     apiserver_url = _guess_apiserver(apiserver_url)
@@ -797,14 +830,15 @@ def delete_secret(namespace, name, apiserver_url=None, force=True):
 
     # we need namespace to delete secret in it
     if not _get_namespaces(apiserver_url, namespace):
-        return {'name': name, 'result': False,
-                'comment': "Namespace doesn't exists, can't delete anything there",
-                'changes': {}}
+        return {
+            "name": name,
+            "result": False,
+            "comment": "Namespace doesn't exists, can't delete anything there",
+            "changes": {},
+        }
 
-    url = "{0}/api/v1/namespaces/{1}/secrets/{2}".format(apiserver_url,
-                                                         namespace, name)
-    res = http.query(url, method='DELETE')
-    if res.get('body'):
-        ret['comment'] = "Removed secret {0} in {1} namespace".format(name,
-                                                                      namespace)
+    url = "{0}/api/v1/namespaces/{1}/secrets/{2}".format(apiserver_url, namespace, name)
+    res = http.query(url, method="DELETE")
+    if res.get("body"):
+        ret["comment"] = "Removed secret {0} in {1} namespace".format(name, namespace)
     return ret
