@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Module for running fmadm and fmdump on Solaris
 
 :maintainer:    Jorge Schrauwen <sjorge@blackdot.be>
@@ -7,63 +7,63 @@ Module for running fmadm and fmdump on Solaris
 :platform:      solaris,illumos
 
 .. versionadded:: 2016.3.0
-'''
-from __future__ import absolute_import, unicode_literals, print_function
+"""
+from __future__ import absolute_import, print_function, unicode_literals
 
 # Import Python libs
 import logging
 
+import salt.utils.decorators as decorators
+
 # Import Salt libs
 import salt.utils.path
 import salt.utils.platform
-import salt.utils.decorators as decorators
 from salt.utils.odict import OrderedDict
 
 log = logging.getLogger(__name__)
 
 # Function aliases
 __func_alias__ = {
-    'list_records': 'list',
+    "list_records": "list",
 }
 
 # Define the module's virtual name
-__virtualname__ = 'fmadm'
+__virtualname__ = "fmadm"
 
 
 @decorators.memoize
 def _check_fmadm():
-    '''
+    """
     Looks to see if fmadm is present on the system
-    '''
-    return salt.utils.path.which('fmadm')
+    """
+    return salt.utils.path.which("fmadm")
 
 
 def _check_fmdump():
-    '''
+    """
     Looks to see if fmdump is present on the system
-    '''
-    return salt.utils.path.which('fmdump')
+    """
+    return salt.utils.path.which("fmdump")
 
 
 def __virtual__():
-    '''
+    """
     Provides fmadm only on Solaris
-    '''
-    if salt.utils.platform.is_sunos() and \
-        _check_fmadm() and _check_fmdump():
+    """
+    if salt.utils.platform.is_sunos() and _check_fmadm() and _check_fmdump():
         return __virtualname__
     return (
         False,
-        '{0} module can only be loaded on Solaris with the fault management installed'.format(
+        "{0} module can only be loaded on Solaris with the fault management installed".format(
             __virtualname__
-        )
+        ),
     )
 
 
 def _parse_fmdump(output):
-    '''
+    """
     Parses fmdump output
-    '''
+    """
     result = []
     output = output.split("\n")
 
@@ -74,7 +74,7 @@ def _parse_fmdump(output):
     # parse entries
     for entry in output:
         entry = [item for item in entry.split(" ") if item]
-        entry = ['{0} {1} {2}'.format(entry[0], entry[1], entry[2])] + entry[3:]
+        entry = ["{0} {1} {2}".format(entry[0], entry[1], entry[2])] + entry[3:]
 
         # prepare faults
         fault = OrderedDict()
@@ -87,16 +87,16 @@ def _parse_fmdump(output):
 
 
 def _parse_fmdump_verbose(output):
-    '''
+    """
     Parses fmdump verbose output
-    '''
+    """
     result = []
     output = output.split("\n")
 
     fault = []
     verbose_fault = {}
     for line in output:
-        if line.startswith('TIME'):
+        if line.startswith("TIME"):
             fault.append(line)
             if len(verbose_fault) > 0:
                 result.append(verbose_fault)
@@ -106,14 +106,11 @@ def _parse_fmdump_verbose(output):
             verbose_fault = _parse_fmdump("\n".join(fault))[0]
             fault = []
         elif len(verbose_fault) > 0:
-            if 'details' not in verbose_fault:
-                verbose_fault['details'] = ""
-            if line.strip() == '':
+            if "details" not in verbose_fault:
+                verbose_fault["details"] = ""
+            if line.strip() == "":
                 continue
-            verbose_fault['details'] = '{0}{1}\n'.format(
-                verbose_fault['details'],
-                line
-            )
+            verbose_fault["details"] = "{0}{1}\n".format(verbose_fault["details"], line)
     if len(verbose_fault) > 0:
         result.append(verbose_fault)
 
@@ -121,9 +118,9 @@ def _parse_fmdump_verbose(output):
 
 
 def _parse_fmadm_config(output):
-    '''
+    """
     Parsbb fmdump/fmadm output
-    '''
+    """
     result = []
     output = output.split("\n")
 
@@ -146,8 +143,8 @@ def _parse_fmadm_config(output):
     # keying
     keyed_result = OrderedDict()
     for component in result:
-        keyed_result[component['module']] = component
-        del keyed_result[component['module']]['module']
+        keyed_result[component["module"]] = component
+        del keyed_result[component["module"]]["module"]
 
     result = keyed_result
 
@@ -155,21 +152,17 @@ def _parse_fmadm_config(output):
 
 
 def _fmadm_action_fmri(action, fmri):
-    '''
+    """
     Internal function for fmadm.repqired, fmadm.replaced, fmadm.flush
-    '''
+    """
     ret = {}
     fmadm = _check_fmadm()
-    cmd = '{cmd} {action} {fmri}'.format(
-        cmd=fmadm,
-        action=action,
-        fmri=fmri
-    )
-    res = __salt__['cmd.run_all'](cmd)
-    retcode = res['retcode']
+    cmd = "{cmd} {action} {fmri}".format(cmd=fmadm, action=action, fmri=fmri)
+    res = __salt__["cmd.run_all"](cmd)
+    retcode = res["retcode"]
     result = {}
     if retcode != 0:
-        result['Error'] = res['stderr']
+        result["Error"] = res["stderr"]
     else:
         result = True
 
@@ -177,17 +170,18 @@ def _fmadm_action_fmri(action, fmri):
 
 
 def _parse_fmadm_faulty(output):
-    '''
+    """
     Parse fmadm faulty output
-    '''
+    """
+
     def _merge_data(summary, fault):
         result = {}
-        uuid = summary['event-id']
-        del summary['event-id']
+        uuid = summary["event-id"]
+        del summary["event-id"]
 
         result[uuid] = OrderedDict()
-        result[uuid]['summary'] = summary
-        result[uuid]['fault'] = fault
+        result[uuid]["summary"] = summary
+        result[uuid]["fault"] = fault
         return result
 
     result = {}
@@ -198,7 +192,7 @@ def _parse_fmadm_faulty(output):
 
     for line in output.split("\n"):
         # we hit a divider
-        if line.startswith('-'):
+        if line.startswith("-"):
             if summary and summary_data and fault_data:
                 # we have data, store it and reset
                 result.update(_merge_data(summary_data, fault_data))
@@ -225,20 +219,25 @@ def _parse_fmadm_faulty(output):
         # if we have a header and data, assume the other lines are details
         if summary and summary_data:
             # if line starts with a whitespace and we already have a key, append
-            if line.startswith(' ') and data_key:
+            if line.startswith(" ") and data_key:
                 fault_data[data_key] = "{0}\n{1}".format(
-                    fault_data[data_key],
-                    line.strip()
+                    fault_data[data_key], line.strip()
                 )
             # we have a key : value line, parse it
-            elif ':' in line:
-                line = line.split(':')
+            elif ":" in line:
+                line = line.split(":")
                 data_key = line[0].strip()
                 fault_data[data_key] = ":".join(line[1:]).strip()
                 # note: for some reason Chassis_id is lobbed ofter Platform, fix that here
-                if data_key == 'Platform':
-                    fault_data['Chassis_id'] = fault_data[data_key][fault_data[data_key].index('Chassis_id'):].split(':')[-1].strip()
-                    fault_data[data_key] = fault_data[data_key][0:fault_data[data_key].index('Chassis_id')].strip()
+                if data_key == "Platform":
+                    fault_data["Chassis_id"] = (
+                        fault_data[data_key][fault_data[data_key].index("Chassis_id") :]
+                        .split(":")[-1]
+                        .strip()
+                    )
+                    fault_data[data_key] = fault_data[data_key][
+                        0 : fault_data[data_key].index("Chassis_id")
+                    ].strip()
 
     # we have data, store it and reset
     result.update(_merge_data(summary_data, fault_data))
@@ -247,7 +246,7 @@ def _parse_fmadm_faulty(output):
 
 
 def list_records(after=None, before=None):
-    '''
+    """
     Display fault management logs
 
     after : string
@@ -261,27 +260,27 @@ def list_records(after=None, before=None):
     .. code-block:: bash
 
         salt '*' fmadm.list
-    '''
+    """
     ret = {}
     fmdump = _check_fmdump()
-    cmd = '{cmd}{after}{before}'.format(
+    cmd = "{cmd}{after}{before}".format(
         cmd=fmdump,
-        after=' -t {0}'.format(after) if after else '',
-        before=' -T {0}'.format(before) if before else ''
+        after=" -t {0}".format(after) if after else "",
+        before=" -T {0}".format(before) if before else "",
     )
-    res = __salt__['cmd.run_all'](cmd)
-    retcode = res['retcode']
+    res = __salt__["cmd.run_all"](cmd)
+    retcode = res["retcode"]
     result = {}
     if retcode != 0:
-        result['Error'] = 'error executing fmdump'
+        result["Error"] = "error executing fmdump"
     else:
-        result = _parse_fmdump(res['stdout'])
+        result = _parse_fmdump(res["stdout"])
 
     return result
 
 
 def show(uuid):
-    '''
+    """
     Display log details
 
     uuid: string
@@ -292,26 +291,23 @@ def show(uuid):
     .. code-block:: bash
 
         salt '*' fmadm.show 11b4070f-4358-62fa-9e1e-998f485977e1
-    '''
+    """
     ret = {}
     fmdump = _check_fmdump()
-    cmd = '{cmd} -u {uuid} -V'.format(
-        cmd=fmdump,
-        uuid=uuid
-    )
-    res = __salt__['cmd.run_all'](cmd)
-    retcode = res['retcode']
+    cmd = "{cmd} -u {uuid} -V".format(cmd=fmdump, uuid=uuid)
+    res = __salt__["cmd.run_all"](cmd)
+    retcode = res["retcode"]
     result = {}
     if retcode != 0:
-        result['Error'] = 'error executing fmdump'
+        result["Error"] = "error executing fmdump"
     else:
-        result = _parse_fmdump_verbose(res['stdout'])
+        result = _parse_fmdump_verbose(res["stdout"])
 
     return result
 
 
 def config():
-    '''
+    """
     Display fault manager configuration
 
     CLI Example:
@@ -319,25 +315,23 @@ def config():
     .. code-block:: bash
 
         salt '*' fmadm.config
-    '''
+    """
     ret = {}
     fmadm = _check_fmadm()
-    cmd = '{cmd} config'.format(
-        cmd=fmadm
-    )
-    res = __salt__['cmd.run_all'](cmd)
-    retcode = res['retcode']
+    cmd = "{cmd} config".format(cmd=fmadm)
+    res = __salt__["cmd.run_all"](cmd)
+    retcode = res["retcode"]
     result = {}
     if retcode != 0:
-        result['Error'] = 'error executing fmadm config'
+        result["Error"] = "error executing fmadm config"
     else:
-        result = _parse_fmadm_config(res['stdout'])
+        result = _parse_fmadm_config(res["stdout"])
 
     return result
 
 
 def load(path):
-    '''
+    """
     Load specified fault manager module
 
     path: string
@@ -348,18 +342,15 @@ def load(path):
     .. code-block:: bash
 
         salt '*' fmadm.load /module/path
-    '''
+    """
     ret = {}
     fmadm = _check_fmadm()
-    cmd = '{cmd} load {path}'.format(
-        cmd=fmadm,
-        path=path
-    )
-    res = __salt__['cmd.run_all'](cmd)
-    retcode = res['retcode']
+    cmd = "{cmd} load {path}".format(cmd=fmadm, path=path)
+    res = __salt__["cmd.run_all"](cmd)
+    retcode = res["retcode"]
     result = {}
     if retcode != 0:
-        result['Error'] = res['stderr']
+        result["Error"] = res["stderr"]
     else:
         result = True
 
@@ -367,7 +358,7 @@ def load(path):
 
 
 def unload(module):
-    '''
+    """
     Unload specified fault manager module
 
     module: string
@@ -378,18 +369,15 @@ def unload(module):
     .. code-block:: bash
 
         salt '*' fmadm.unload software-response
-    '''
+    """
     ret = {}
     fmadm = _check_fmadm()
-    cmd = '{cmd} unload {module}'.format(
-        cmd=fmadm,
-        module=module
-    )
-    res = __salt__['cmd.run_all'](cmd)
-    retcode = res['retcode']
+    cmd = "{cmd} unload {module}".format(cmd=fmadm, module=module)
+    res = __salt__["cmd.run_all"](cmd)
+    retcode = res["retcode"]
     result = {}
     if retcode != 0:
-        result['Error'] = res['stderr']
+        result["Error"] = res["stderr"]
     else:
         result = True
 
@@ -397,7 +385,7 @@ def unload(module):
 
 
 def reset(module, serd=None):
-    '''
+    """
     Reset module or sub-component
 
     module: string
@@ -410,19 +398,17 @@ def reset(module, serd=None):
     .. code-block:: bash
 
         salt '*' fmadm.reset software-response
-    '''
+    """
     ret = {}
     fmadm = _check_fmadm()
-    cmd = '{cmd} reset {serd}{module}'.format(
-        cmd=fmadm,
-        serd='-s {0} '.format(serd) if serd else '',
-        module=module
+    cmd = "{cmd} reset {serd}{module}".format(
+        cmd=fmadm, serd="-s {0} ".format(serd) if serd else "", module=module
     )
-    res = __salt__['cmd.run_all'](cmd)
-    retcode = res['retcode']
+    res = __salt__["cmd.run_all"](cmd)
+    retcode = res["retcode"]
     result = {}
     if retcode != 0:
-        result['Error'] = res['stderr']
+        result["Error"] = res["stderr"]
     else:
         result = True
 
@@ -430,7 +416,7 @@ def reset(module, serd=None):
 
 
 def flush(fmri):
-    '''
+    """
     Flush cached state for resource
 
     fmri: string
@@ -441,12 +427,12 @@ def flush(fmri):
     .. code-block:: bash
 
         salt '*' fmadm.flush fmri
-    '''
-    return _fmadm_action_fmri('flush', fmri)
+    """
+    return _fmadm_action_fmri("flush", fmri)
 
 
 def repaired(fmri):
-    '''
+    """
     Notify fault manager that resource has been repaired
 
     fmri: string
@@ -457,12 +443,12 @@ def repaired(fmri):
     .. code-block:: bash
 
         salt '*' fmadm.repaired fmri
-    '''
-    return _fmadm_action_fmri('repaired', fmri)
+    """
+    return _fmadm_action_fmri("repaired", fmri)
 
 
 def replaced(fmri):
-    '''
+    """
     Notify fault manager that resource has been replaced
 
     fmri: string
@@ -473,12 +459,12 @@ def replaced(fmri):
     .. code-block:: bash
 
         salt '*' fmadm.repaired fmri
-    '''
-    return _fmadm_action_fmri('replaced', fmri)
+    """
+    return _fmadm_action_fmri("replaced", fmri)
 
 
 def acquit(fmri):
-    '''
+    """
     Acquit resource or acquit case
 
     fmri: string
@@ -489,12 +475,12 @@ def acquit(fmri):
     .. code-block:: bash
 
         salt '*' fmadm.acquit fmri | uuid
-    '''
-    return _fmadm_action_fmri('acquit', fmri)
+    """
+    return _fmadm_action_fmri("acquit", fmri)
 
 
 def faulty():
-    '''
+    """
     Display list of faulty resources
 
     CLI Example:
@@ -502,23 +488,21 @@ def faulty():
     .. code-block:: bash
 
         salt '*' fmadm.faulty
-    '''
+    """
     fmadm = _check_fmadm()
-    cmd = '{cmd} faulty'.format(
-        cmd=fmadm,
-    )
-    res = __salt__['cmd.run_all'](cmd)
+    cmd = "{cmd} faulty".format(cmd=fmadm,)
+    res = __salt__["cmd.run_all"](cmd)
     result = {}
-    if res['stdout'] == '':
+    if res["stdout"] == "":
         result = False
     else:
-        result = _parse_fmadm_faulty(res['stdout'])
+        result = _parse_fmadm_faulty(res["stdout"])
 
     return result
 
 
 def healthy():
-    '''
+    """
     Return whether fmadm is reporting faults
 
     CLI Example:
@@ -526,7 +510,8 @@ def healthy():
     .. code-block:: bash
 
         salt '*' fmadm.healthy
-    '''
+    """
     return False if faulty() else True
 
+
 # vim: tabstop=4 expandtab shiftwidth=4 softtabstop=4
