@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Proxy Minion interface module for managing VMware ESXi hosts.
 
 .. versionadded:: 2015.8.4
@@ -135,7 +135,7 @@ may be updating for an ESXi host either via the
 execution module function or via the
 :mod:`esxi.password_present <salt.states.esxi.password_present>` state
 function. This way, after the password is changed, you should not need to
-restart the proxy minion--it should just pick up the the new password
+restart the proxy minion--it should just pick up the new password
 provided in the list. You can then change pillar at will to move that
 password to the front and retire the unused ones.
 
@@ -268,24 +268,23 @@ Associated states are thoroughly documented in
 to find an example structure for Pillar as well as an example ``.sls`` file
 for standing up an ESXi host from scratch.
 
-'''
+"""
 
-# Import Python Libs
 from __future__ import absolute_import, print_function, unicode_literals
+
 import logging
 import os
 
-# Import Salt Libs
-from salt.exceptions import SaltSystemExit, InvalidConfigError
 from salt.config.schemas.esxi import EsxiProxySchema
+from salt.exceptions import InvalidConfigError, SaltSystemExit
 from salt.utils.dictupdate import merge
 
 # This must be present or the Salt loader won't load this module.
-__proxyenabled__ = ['esxi']
+__proxyenabled__ = ["esxi"]
 
-# External libraries
 try:
     import jsonschema
+
     HAS_JSONSCHEMA = True
 except ImportError:
     HAS_JSONSCHEMA = False
@@ -298,145 +297,150 @@ DETAILS = {}
 # Set up logging
 log = logging.getLogger(__file__)
 # Define the module's virtual name
-__virtualname__ = 'esxi'
+__virtualname__ = "esxi"
 
 
 def __virtual__():
-    '''
+    """
     Only load if the ESXi execution module is available.
-    '''
+    """
     if HAS_JSONSCHEMA:
         return __virtualname__
 
-    return False, 'The ESXi Proxy Minion module did not load.'
+    return False, "The ESXi Proxy Minion module did not load."
 
 
 def init(opts):
-    '''
+    """
     This function gets called when the proxy starts up. For
     ESXi devices, the host, login credentials, and, if configured,
     the protocol and port are cached.
-    '''
-    log.debug('Initting esxi proxy module in process %s', os.getpid())
-    log.debug('Validating esxi proxy input')
+    """
+    log.debug("Initting esxi proxy module in process %s", os.getpid())
+    log.debug("Validating esxi proxy input")
     schema = EsxiProxySchema.serialize()
-    log.trace('esxi_proxy_schema = %s', schema)
-    proxy_conf = merge(opts.get('proxy', {}), __pillar__.get('proxy', {}))
-    log.trace('proxy_conf = %s', proxy_conf)
+    log.trace("esxi_proxy_schema = %s", schema)
+    proxy_conf = merge(opts.get("proxy", {}), __pillar__.get("proxy", {}))
+    log.trace("proxy_conf = %s", proxy_conf)
     try:
         jsonschema.validate(proxy_conf, schema)
     except jsonschema.exceptions.ValidationError as exc:
         raise InvalidConfigError(exc)
 
-    DETAILS['proxytype'] = proxy_conf['proxytype']
-    if ('host' not in proxy_conf) and ('vcenter' not in proxy_conf):
-        log.critical('Neither \'host\' nor \'vcenter\' keys found in pillar '
-                     'for this proxy.')
+    DETAILS["proxytype"] = proxy_conf["proxytype"]
+    if ("host" not in proxy_conf) and ("vcenter" not in proxy_conf):
+        log.critical(
+            "Neither 'host' nor 'vcenter' keys found in pillar " "for this proxy."
+        )
         return False
-    if 'host' in proxy_conf:
+    if "host" in proxy_conf:
         # We have started the proxy by connecting directly to the host
-        if 'username' not in proxy_conf:
-            log.critical('No \'username\' key found in pillar for this proxy.')
+        if "username" not in proxy_conf:
+            log.critical("No 'username' key found in pillar for this proxy.")
             return False
-        if 'passwords' not in proxy_conf:
-            log.critical('No \'passwords\' key found in pillar for this proxy.')
+        if "passwords" not in proxy_conf:
+            log.critical("No 'passwords' key found in pillar for this proxy.")
             return False
-        host = proxy_conf['host']
+        host = proxy_conf["host"]
 
         # Get the correct login details
         try:
             username, password = find_credentials(host)
         except SaltSystemExit as err:
-            log.critical('Error: %s', err)
+            log.critical("Error: %s", err)
             return False
 
         # Set configuration details
-        DETAILS['host'] = host
-        DETAILS['username'] = username
-        DETAILS['password'] = password
-        DETAILS['protocol'] = proxy_conf.get('protocol')
-        DETAILS['port'] = proxy_conf.get('port')
+        DETAILS["host"] = host
+        DETAILS["username"] = username
+        DETAILS["password"] = password
+        DETAILS["protocol"] = proxy_conf.get("protocol")
+        DETAILS["port"] = proxy_conf.get("port")
         return True
 
-    if 'vcenter' in proxy_conf:
-        vcenter = proxy_conf['vcenter']
-        if not proxy_conf.get('esxi_host'):
-            log.critical('No \'esxi_host\' key found in pillar for this proxy.')
-        DETAILS['esxi_host'] = proxy_conf['esxi_host']
+    if "vcenter" in proxy_conf:
+        vcenter = proxy_conf["vcenter"]
+        if not proxy_conf.get("esxi_host"):
+            log.critical("No 'esxi_host' key found in pillar for this proxy.")
+        DETAILS["esxi_host"] = proxy_conf["esxi_host"]
         # We have started the proxy by connecting via the vCenter
-        if 'mechanism' not in proxy_conf:
-            log.critical('No \'mechanism\' key found in pillar for this proxy.')
+        if "mechanism" not in proxy_conf:
+            log.critical("No 'mechanism' key found in pillar for this proxy.")
             return False
-        mechanism = proxy_conf['mechanism']
+        mechanism = proxy_conf["mechanism"]
         # Save mandatory fields in cache
-        for key in ('vcenter', 'mechanism'):
+        for key in ("vcenter", "mechanism"):
             DETAILS[key] = proxy_conf[key]
 
-        if mechanism == 'userpass':
-            if 'username' not in proxy_conf:
-                log.critical('No \'username\' key found in pillar for this '
-                             'proxy.')
+        if mechanism == "userpass":
+            if "username" not in proxy_conf:
+                log.critical("No 'username' key found in pillar for this " "proxy.")
                 return False
-            if 'passwords' not in proxy_conf and \
-                len(proxy_conf['passwords']) > 0:
+            if "passwords" not in proxy_conf and len(proxy_conf["passwords"]) > 0:
 
-                log.critical('Mechanism is set to \'userpass\' , but no '
-                             '\'passwords\' key found in pillar for this '
-                             'proxy.')
+                log.critical(
+                    "Mechanism is set to 'userpass' , but no "
+                    "'passwords' key found in pillar for this "
+                    "proxy."
+                )
                 return False
-            for key in ('username', 'passwords'):
+            for key in ("username", "passwords"):
                 DETAILS[key] = proxy_conf[key]
-        elif mechanism == 'sspi':
-            if 'domain' not in proxy_conf:
-                log.critical('Mechanism is set to \'sspi\' , but no '
-                             '\'domain\' key found in pillar for this proxy.')
+        elif mechanism == "sspi":
+            if "domain" not in proxy_conf:
+                log.critical(
+                    "Mechanism is set to 'sspi' , but no "
+                    "'domain' key found in pillar for this proxy."
+                )
                 return False
-            if 'principal' not in proxy_conf:
-                log.critical('Mechanism is set to \'sspi\' , but no '
-                             '\'principal\' key found in pillar for this '
-                             'proxy.')
+            if "principal" not in proxy_conf:
+                log.critical(
+                    "Mechanism is set to 'sspi' , but no "
+                    "'principal' key found in pillar for this "
+                    "proxy."
+                )
                 return False
-            for key in ('domain', 'principal'):
+            for key in ("domain", "principal"):
                 DETAILS[key] = proxy_conf[key]
 
-        if mechanism == 'userpass':
+        if mechanism == "userpass":
             # Get the correct login details
-            log.debug('Retrieving credentials and testing vCenter connection'
-                      ' for mehchanism \'userpass\'')
+            log.debug(
+                "Retrieving credentials and testing vCenter connection"
+                " for mehchanism 'userpass'"
+            )
             try:
-                username, password = find_credentials(DETAILS['vcenter'])
-                DETAILS['password'] = password
+                username, password = find_credentials(DETAILS["vcenter"])
+                DETAILS["password"] = password
             except SaltSystemExit as err:
-                log.critical('Error: %s', err)
+                log.critical("Error: %s", err)
                 return False
 
     # Save optional
-    DETAILS['protocol'] = proxy_conf.get('protocol', 'https')
-    DETAILS['port'] = proxy_conf.get('port', '443')
-    DETAILS['credstore'] = proxy_conf.get('credstore')
+    DETAILS["protocol"] = proxy_conf.get("protocol", "https")
+    DETAILS["port"] = proxy_conf.get("port", "443")
+    DETAILS["credstore"] = proxy_conf.get("credstore")
 
 
 def grains():
-    '''
+    """
     Get the grains from the proxy device.
-    '''
+    """
     if not GRAINS_CACHE:
-        return _grains(DETAILS['host'],
-                       DETAILS['protocol'],
-                       DETAILS['port'])
+        return _grains(DETAILS["host"], DETAILS["protocol"], DETAILS["port"])
     return GRAINS_CACHE
 
 
 def grains_refresh():
-    '''
+    """
     Refresh the grains from the proxy device.
-    '''
+    """
     GRAINS_CACHE = {}
     return grains()
 
 
 def ping():
-    '''
+    """
     Returns True if connection is to be done via a vCenter (no connection is attempted).
     Check to see if the host is responding when connecting directly via an ESXi
     host.
@@ -446,17 +450,19 @@ def ping():
     .. code-block:: bash
 
         salt esxi-host test.ping
-    '''
-    if DETAILS.get('esxi_host'):
+    """
+    if DETAILS.get("esxi_host"):
         return True
     else:
         # TODO Check connection if mechanism is SSPI
-        if DETAILS['mechanism'] == 'userpass':
-            find_credentials(DETAILS['host'])
+        if DETAILS["mechanism"] == "userpass":
+            find_credentials(DETAILS["host"])
             try:
-                __salt__['vsphere.system_info'](host=DETAILS['host'],
-                                                username=DETAILS['username'],
-                                                password=DETAILS['password'])
+                __salt__["vsphere.system_info"](
+                    host=DETAILS["host"],
+                    username=DETAILS["username"],
+                    password=DETAILS["password"],
+                )
             except SaltSystemExit as err:
                 log.warning(err)
                 return False
@@ -464,15 +470,15 @@ def ping():
 
 
 def shutdown():
-    '''
+    """
     Shutdown the connection to the proxy device. For this proxy,
     shutdown is a no-op.
-    '''
-    log.debug('ESXi proxy shutdown() called...')
+    """
+    log.debug("ESXi proxy shutdown() called...")
 
 
 def ch_config(cmd, *args, **kwargs):
-    '''
+    """
     This function is called by the
     :mod:`salt.modules.esxi.cmd <salt.modules.esxi.cmd>` shim.
     It then calls whatever is passed in ``cmd`` inside the
@@ -488,71 +494,71 @@ def ch_config(cmd, *args, **kwargs):
     kwargs
         Keyword arguments that need to be passed to that command.
 
-    '''
+    """
     # Strip the __pub_ keys...is there a better way to do this?
     for k in kwargs:
-        if k.startswith('__pub_'):
+        if k.startswith("__pub_"):
             kwargs.pop(k)
 
-    kwargs['host'] = DETAILS['host']
-    kwargs['username'] = DETAILS['username']
-    kwargs['password'] = DETAILS['password']
-    kwargs['port'] = DETAILS['port']
-    kwargs['protocol'] = DETAILS['protocol']
-    kwargs['credstore'] = DETAILS['credstore']
+    kwargs["host"] = DETAILS["host"]
+    kwargs["username"] = DETAILS["username"]
+    kwargs["password"] = DETAILS["password"]
+    kwargs["port"] = DETAILS["port"]
+    kwargs["protocol"] = DETAILS["protocol"]
+    kwargs["credstore"] = DETAILS["credstore"]
 
-    if 'vsphere.' + cmd not in __salt__:
-        return {'retcode': -1, 'message': 'vsphere.' + cmd + ' is not available.'}
+    if "vsphere." + cmd not in __salt__:
+        return {"retcode": -1, "message": "vsphere." + cmd + " is not available."}
     else:
-        return __salt__['vsphere.' + cmd](*args, **kwargs)
+        return __salt__["vsphere." + cmd](*args, **kwargs)
 
 
 def find_credentials(host):
-    '''
+    """
     Cycle through all the possible credentials and return the first one that
     works.
-    '''
-    user_names = [__pillar__['proxy'].get('username', 'root')]
-    passwords = __pillar__['proxy']['passwords']
+    """
+    user_names = [__pillar__["proxy"].get("username", "root")]
+    passwords = __pillar__["proxy"]["passwords"]
     for user in user_names:
         for password in passwords:
             try:
                 # Try to authenticate with the given user/password combination
-                ret = __salt__['vsphere.system_info'](host=host,
-                                                      username=user,
-                                                      password=password)
+                ret = __salt__["vsphere.system_info"](
+                    host=host, username=user, password=password
+                )
             except SaltSystemExit:
                 # If we can't authenticate, continue on to try the next password.
                 continue
             # If we have data returned from above, we've successfully authenticated.
             if ret:
-                DETAILS['username'] = user
-                DETAILS['password'] = password
+                DETAILS["username"] = user
+                DETAILS["password"] = password
                 return user, password
     # We've reached the end of the list without successfully authenticating.
-    raise SaltSystemExit('Cannot complete login due to an incorrect user name or password.')
+    raise SaltSystemExit(
+        "Cannot complete login due to an incorrect user name or password."
+    )
 
 
 def _grains(host, protocol=None, port=None):
-    '''
+    """
     Helper function to the grains from the proxied device.
-    '''
-    username, password = find_credentials(DETAILS['host'])
-    ret = __salt__['vsphere.system_info'](host=host,
-                                          username=username,
-                                          password=password,
-                                          protocol=protocol,
-                                          port=port)
+    """
+    username, password = find_credentials(DETAILS["host"])
+    ret = __salt__["vsphere.system_info"](
+        host=host, username=username, password=password, protocol=protocol, port=port
+    )
     GRAINS_CACHE.update(ret)
     return GRAINS_CACHE
 
 
 def is_connected_via_vcenter():
-    return True if 'vcenter' in DETAILS else False
+    return True if "vcenter" in DETAILS else False
 
 
 def get_details():
-    '''
+    """
     Return the proxy details
-    '''
+    """
     return DETAILS
