@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Management of OpenStack Neutron Security Group Rules
 ====================================================
 
@@ -27,24 +27,27 @@ Example States
         - name: security_group1
         - description: "Very Secure Security Group"
         - project_id: 1dcac318a83b4610b7a7f7ba01465548
-'''
+"""
 
 from __future__ import absolute_import, print_function, unicode_literals
 
-__virtualname__ = 'neutron_secgroup_rule'
+__virtualname__ = "neutron_secgroup_rule"
 
 
 def __virtual__():
-    if 'neutronng.list_subnets' in __salt__:
+    if "neutronng.list_subnets" in __salt__:
         return __virtualname__
-    return (False, 'The neutronng execution module failed to load:\
-                    shade python module is not available')
+    return (
+        False,
+        "The neutronng execution module failed to load:\
+                    shade python module is not available",
+    )
 
 
 def _rule_compare(rule1, rule2):
-    '''
+    """
     Compare the common keys between security group rules against eachother
-    '''
+    """
 
     commonkeys = set(rule1.keys()).intersection(rule2.keys())
     for key in commonkeys:
@@ -54,7 +57,7 @@ def _rule_compare(rule1, rule2):
 
 
 def present(name, auth=None, **kwargs):
-    '''
+    """
     Ensure a security group rule exists
 
     defaults: port_range_min=None, port_range_max=None, protocol=None,
@@ -71,64 +74,60 @@ def present(name, auth=None, **kwargs):
         The protocol that is matched by the security group rule.
         Valid values are None, tcp, udp, and icmp.
 
-    '''
-    ret = {'name': name,
-           'changes': {},
-           'result': True,
-           'comment': ''}
+    """
+    ret = {"name": name, "changes": {}, "result": True, "comment": ""}
 
-    __salt__['neutronng.setup_clouds'](auth)
+    kwargs = __utils__["args.clean_kwargs"](**kwargs)
 
-    if 'project_name' in kwargs:
-        kwargs['project_id'] = kwargs['project_name']
-        del kwargs['project_name']
+    __salt__["neutronng.setup_clouds"](auth)
 
-    project = __salt__['keystoneng.project_get'](
-        name=kwargs['project_id'])
+    if "project_name" in kwargs:
+        kwargs["project_id"] = kwargs["project_name"]
+        del kwargs["project_name"]
+
+    project = __salt__["keystoneng.project_get"](name=kwargs["project_id"])
 
     if project is None:
-        ret['result'] = False
-        ret['comment'] = "Project does not exist"
+        ret["result"] = False
+        ret["comment"] = "Project does not exist"
         return ret
 
-    secgroup = __salt__['neutronng.security_group_get'](
-        name=name,
-        filters={'tenant_id': project.id}
+    secgroup = __salt__["neutronng.security_group_get"](
+        name=name, filters={"tenant_id": project.id}
     )
 
     if secgroup is None:
-        ret['result'] = False
-        ret['changes'] = {},
-        ret['comment'] = 'Security Group does not exist {}'.format(name)
+        ret["result"] = False
+        ret["changes"] = ({},)
+        ret["comment"] = "Security Group does not exist {}".format(name)
         return ret
 
     # we have to search through all secgroup rules for a possible match
     rule_exists = None
-    for rule in secgroup['security_group_rules']:
+    for rule in secgroup["security_group_rules"]:
         if _rule_compare(rule, kwargs) is True:
             rule_exists = True
 
     if rule_exists is None:
-        if __opts__['test'] is True:
-            ret['result'] = None
-            ret['changes'] = kwargs
-            ret['pchanges'] = ret['changes']
-            ret['comment'] = 'Security Group rule will be created.'
+        if __opts__["test"] is True:
+            ret["result"] = None
+            ret["changes"] = kwargs
+            ret["comment"] = "Security Group rule will be created."
             return ret
 
         # The variable differences are a little clumsy right now
-        kwargs['secgroup_name_or_id'] = secgroup
+        kwargs["secgroup_name_or_id"] = secgroup
 
-        new_rule = __salt__['neutronng.security_group_rule_create'](**kwargs)
-        ret['changes'] = new_rule
-        ret['comment'] = 'Created security group rule'
+        new_rule = __salt__["neutronng.security_group_rule_create"](**kwargs)
+        ret["changes"] = new_rule
+        ret["comment"] = "Created security group rule"
         return ret
 
     return ret
 
 
 def absent(name, auth=None, **kwargs):
-    '''
+    """
     Ensure a security group rule does not exist
 
     name
@@ -139,42 +138,37 @@ def absent(name, auth=None, **kwargs):
 
     project_id
         id of project to delete rule from
-    '''
-    rule_id = kwargs['rule_id']
-    ret = {'name': rule_id,
-           'changes': {},
-           'result': True,
-           'comment': ''}
+    """
+    rule_id = kwargs["rule_id"]
+    ret = {"name": rule_id, "changes": {}, "result": True, "comment": ""}
 
-    __salt__['neutronng.setup_clouds'](auth)
+    __salt__["neutronng.setup_clouds"](auth)
 
-    secgroup = __salt__['neutronng.security_group_get'](
-        name=name,
-        filters={'tenant_id': kwargs['project_id']}
+    secgroup = __salt__["neutronng.security_group_get"](
+        name=name, filters={"tenant_id": kwargs["project_id"]}
     )
 
     # no need to delete a rule if the security group doesn't exist
     if secgroup is None:
-        ret['comment'] = "security group does not exist"
+        ret["comment"] = "security group does not exist"
         return ret
 
     # This should probably be done with compare on fields instead of
     # rule_id in the future
     rule_exists = None
-    for rule in secgroup['security_group_rules']:
+    for rule in secgroup["security_group_rules"]:
         if _rule_compare(rule, {"id": rule_id}) is True:
             rule_exists = True
 
     if rule_exists:
-        if __opts__['test'] is True:
-            ret['result'] = None
-            ret['changes'] = {'id': kwargs['rule_id']}
-            ret['pchanges'] = ret['changes']
-            ret['comment'] = 'Security group rule will be deleted.'
+        if __opts__["test"]:
+            ret["result"] = None
+            ret["changes"] = {"id": kwargs["rule_id"]}
+            ret["comment"] = "Security group rule will be deleted."
             return ret
 
-        __salt__['neutronng.security_group_rule_delete'](rule_id=rule_id)
-        ret['changes']['id'] = rule_id
-        ret['comment'] = 'Deleted security group rule'
+        __salt__["neutronng.security_group_rule_delete"](rule_id=rule_id)
+        ret["changes"]["id"] = rule_id
+        ret["comment"] = "Deleted security group rule"
 
     return ret
