@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
     Salt proxy state
 
     .. versionadded:: 2015.8.2
@@ -22,16 +22,16 @@
     within /etc/salt/proxy (if /etc/salt/proxy doesn't exists)
     and start the salt-proxy process (default true),
     if it isn't already running.
-'''
-from __future__ import absolute_import
+"""
+from __future__ import absolute_import, print_function, unicode_literals
 
 import logging
 
 log = logging.getLogger(__name__)
 
 
-def configure_proxy(name, proxyname='p8000', start=True):
-    '''
+def configure_proxy(name, proxyname="p8000", start=True):
+    """
     Create the salt proxy file and start the proxy process
     if required
 
@@ -52,11 +52,7 @@ def configure_proxy(name, proxyname='p8000', start=True):
                 - proxyname: p8000
                 - start: True
 
-    '''
-    ret = __salt__['salt_proxy.configure_proxy'](proxyname,
-                                                 start=start)
-    ret.update({
-        'name': name,
-        'comment': '{0} config messages'.format(name)
-    })
+    """
+    ret = __salt__["salt_proxy.configure_proxy"](proxyname, start=start)
+    ret.update({"name": name, "comment": "{0} config messages".format(name)})
     return ret
