@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
     :codeauthor: Pedro Algarvio (pedro@algarvio.me)
     :codeauthor: Thomas Jackson (jacksontj.89@gmail.com)
 
@@ -8,13 +8,13 @@
     ~~~~~~~~~~~~~~~~~~
 
     Context managers used throughout Salt's source code.
-'''
+"""
 from __future__ import absolute_import, print_function, unicode_literals
 
 # Import python libs
 import copy
 import threading
-import collections
+from collections.abc import MutableMapping
 from contextlib import contextmanager
 
 from salt.ext import six
@@ -22,11 +22,11 @@ from salt.ext import six
 
 @contextmanager
 def func_globals_inject(func, **overrides):
-    '''
+    """
     Override specific variables within a function's global context.
-    '''
+    """
     # recognize methods
-    if hasattr(func, 'im_func'):
+    if hasattr(func, "im_func"):
         func = func.__func__
 
     # Get a reference to the function globals dictionary
@@ -57,14 +57,14 @@ def func_globals_inject(func, **overrides):
         del func_globals[injected]
 
 
-class ContextDict(collections.MutableMapping):
-    '''
+class ContextDict(MutableMapping):
+    """
     A context manager that saves some per-thread state globally.
     Intended for use with Tornado's StackContext.
 
     Provide arbitrary data as kwargs upon creation,
     then allow any children to override the values of the parent.
-    '''
+    """
 
     def __init__(self, threadsafe=False, **data):
         # state should be thread local, so this object can be threadsafe
@@ -78,10 +78,10 @@ class ContextDict(collections.MutableMapping):
 
     @property
     def active(self):
-        '''Determine if this ContextDict is currently overridden
+        """Determine if this ContextDict is currently overridden
         Since the ContextDict can be overridden in each thread, we check whether
         the _state.data is set or not.
-        '''
+        """
         try:
             return self._state.data is not None
         except AttributeError:
@@ -89,10 +89,12 @@ class ContextDict(collections.MutableMapping):
 
     # TODO: rename?
     def clone(self, **kwargs):
-        '''
+        """
         Clone this context, and return the ChildContextDict
-        '''
-        child = ChildContextDict(parent=self, threadsafe=self._threadsafe, overrides=kwargs)
+        """
+        child = ChildContextDict(
+            parent=self, threadsafe=self._threadsafe, overrides=kwargs
+        )
         return child
 
     def __setitem__(self, key, val):
@@ -142,10 +144,11 @@ class ContextDict(collections.MutableMapping):
         return new_obj
 
 
-class ChildContextDict(collections.MutableMapping):
-    '''An overrideable child of ContextDict
+class ChildContextDict(MutableMapping):
+    """An overrideable child of ContextDict
+
+    """
 
-    '''
     def __init__(self, parent, overrides=None, threadsafe=False):
         self.parent = parent
         self._data = {} if overrides is None else overrides
@@ -181,7 +184,7 @@ class ChildContextDict(collections.MutableMapping):
         return iter(self._data)
 
     def __enter__(self):
-        if hasattr(self.parent._state, 'data'):
+        if hasattr(self.parent._state, "data"):
             # Save old data to support nested calls
             self._old_data = self.parent._state.data
         self.parent._state.data = self._data
@@ -190,23 +193,19 @@ class ChildContextDict(collections.MutableMapping):
         self.parent._state.data = self._old_data
 
 
-class NamespacedDictWrapper(collections.MutableMapping, dict):
-    '''
+class NamespacedDictWrapper(MutableMapping, dict):
+    """
     Create a dict which wraps another dict with a specific prefix of key(s)
 
     MUST inherit from dict to serialize through msgpack correctly
-    '''
+    """
 
-    def __init__(self, d, pre_keys, override_name=None):  # pylint: disable=W0231
+    def __init__(self, d, pre_keys):  # pylint: disable=W0231
         self.__dict = d
         if isinstance(pre_keys, six.string_types):
             self.pre_keys = (pre_keys,)
         else:
             self.pre_keys = pre_keys
-        if override_name:
-            self.__class__.__module__ = 'salt'
-            # __name__ can't be assigned a unicode
-            self.__class__.__name__ = str(override_name)  # future lint: disable=blacklisted-function
         super(NamespacedDictWrapper, self).__init__(self._dict())
 
     def _dict(self):
@@ -234,12 +233,12 @@ class NamespacedDictWrapper(collections.MutableMapping, dict):
         return iter(self._dict())
 
     def __copy__(self):
-        return type(self)(copy.copy(self.__dict),
-                          copy.copy(self.pre_keys))
+        return type(self)(copy.copy(self.__dict), copy.copy(self.pre_keys))
 
     def __deepcopy__(self, memo):
-        return type(self)(copy.deepcopy(self.__dict, memo),
-                          copy.deepcopy(self.pre_keys, memo))
+        return type(self)(
+            copy.deepcopy(self.__dict, memo), copy.deepcopy(self.pre_keys, memo)
+        )
 
     def __str__(self):
         return self._dict().__str__()
